@@ -26,11 +26,11 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, Process):
             return obj.__dict__
-        elif isinstance(obj, AddTask):
+        elif isinstance(obj, AddProcess):
             return obj.__dict__
-        elif isinstance(obj, MoveOperation):
+        elif isinstance(obj, MoveTask):
             return obj.__dict__
-        elif isinstance(obj, CompleteOperation):
+        elif isinstance(obj, CompleteTask):
             return obj.__dict__
         elif isinstance(obj, Destination):
             return obj.value
@@ -68,12 +68,12 @@ class JsonDecoder(json.JSONDecoder):
                 return Product(**obj)
             if '_type' in obj and obj['_type'] == 'process':
                 return Process(**obj)
-            if '_type' in obj and obj['_type'] == 'add_task':
-                return AddTask(**obj)
-            if '_type' in obj and obj['_type'] == 'move_operation':
-                return MoveOperation(**obj)
-            if '_type' in obj and obj['_type'] == 'complete_operation':
-                return CompleteOperation(**obj)
+            if '_type' in obj and obj['_type'] == 'add_process':
+                return AddProcess(**obj)
+            if '_type' in obj and obj['_type'] == 'move_task':
+                return MoveTask(**obj)
+            if '_type' in obj and obj['_type'] == 'complete_task':
+                return CompleteTask(**obj)
             if '_type' in obj and obj['_type'] == 'confirm_needed':
                 return ConfirmNeeded(**obj)
         return obj
