@@ -4,7 +4,8 @@ from typing import List
 class Task:
 
     def __init__(self, uuid: str, name: str, product_uuid: str, pose: dict, automated: bool = False,
-                 conditions: List[str] = None, description: str = "", _type: str = ''):
+                 conditions: List[str] = None, conditions_fulfilled: bool = True, description: str = "",
+                 _type: str = ''):
         conditions = conditions if conditions else []
         assert type(uuid) == str
         assert type(name) == str
@@ -12,6 +13,7 @@ class Task:
         assert type(pose) == dict
         assert type(automated) == bool
         assert type(conditions) == list, f"Type of conditions: {type(conditions)}"
+        assert type(conditions_fulfilled) == bool
         assert type(description) == str
         for key in ['x', 'y', 'z', 'rx', 'ry', 'rz']:
             assert key in pose, f"The following must be in pose-dict: {key}. Pose: {pose}"
@@ -24,6 +26,7 @@ class Task:
         self.pose = pose
         self.automated = automated
         self.conditions = conditions
+        self.conditions_fulfilled = conditions_fulfilled
         self.description = description
 
     def __eq__(self, other: object) -> bool:
@@ -33,6 +36,7 @@ class Task:
                    and other.pose == self.pose \
                    and other.automated == self.automated \
                    and other.conditions == self.conditions \
+                   and other.conditions_fulfilled == self.conditions_fulfilled \
                    and other.description == self.description
         return False
 
@@ -41,4 +45,5 @@ class Task:
 
     def __repr__(self):
         return f"<uuid={self.uuid},name={self.name},product_uuid={self.product_uuid},pose={self.pose}," \
-               f"automated={self.automated},conditions={self.conditions},description={self.description}>"
+               f"automated={self.automated},conditions={self.conditions}," \
+               f"conditions_fulfilled={self.conditions_fulfilled},description={self.description}>"
