@@ -45,13 +45,13 @@ class Test(TestCase):
         assert type(pose_string) == str
         assert pose_string == '{"_type": "pose", "name": "waypoint_1", ' \
                               '"position": {"_type": "vector3", "x": 1, "y": 2, "z": 3}, ' \
-                              '"orientation": {"_type": "vector3", "x": -1.1, "y": -1.2, "z": 1.3}}'
+                              '"rotation": {"_type": "vector3", "x": -1.1, "y": -1.2, "z": 1.3}}'
 
         pose_decoded: Pose = json_decode(pose_string)
         assert type(pose_decoded) == Pose, f"Expected object of type {Pose}"
         assert pose_decoded.name == self.name
         assert pose_decoded.position == self.position
-        assert pose_decoded.orientation == self.orientation
+        assert pose_decoded.rotation == self.orientation
         assert pose_decoded == self.pose
 
     def test_pose_equals(self):
